@@ -13,15 +13,14 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+import shutil
 import unittest
 import sys
 import os
-
+from wstunnel.test import setup_logging, fixture, clean_logging
 
 __author__ = 'fabio'
 
-fixture = os.path.join(os.path.dirname(__file__), "fixture")
-
 if not sys.platform.startswith("win"):
     import mock
     import yaml
@@ -35,16 +34,8 @@ if not sys.platform.startswith("win"):
         """
 
         def setUp(self):
-            self.log_file = os.path.join(fixture, "logs", "wstun_test_{0}.log".format(os.getpid()))
-            self.pid_file = os.path.join(fixture, "temp", "wstun_test_{0}.log".format(os.getpid()))
-
-            for f in self.log_file, self.pid_file:
-                if not os.path.exists(os.path.dirname(f)):
-                    os.makedirs(os.path.dirname(f))
-                elif os.path.exists(f):
-                    os.remove(f)
-
-            open(self.log_file, 'w').close()
+            self.log_file, self.pid_file = setup_logging()
+            #open(self.log_file, 'w').close()
 
             self.daemon = Daemon(self.pid_file, workdir=fixture)
             self.daemon.hush = lambda **kwargs: 0
@@ -99,6 +90,8 @@ if not sys.platform.startswith("win"):
             """
             Test daemon started when another instance is running
             """
+            if not os.path.exists(os.path.dirname(self.pid_file)):
+                os.makedirs(os.path.dirname(self.pid_file))
             with open(self.pid_file, "w") as pid:
                 pid.write(str(os.getpid()) + "\n")
 
@@ -148,10 +141,7 @@ if not sys.platform.startswith("win"):
 
         def tearDown(self):
             self.daemon.shutdown()
-            for f in self.log_file, self.pid_file:
-                if os.path.exists(f):
-                    os.remove(f)
-
+            clean_logging([self.log_file, self.pid_file])
 
     class WSTunnelClientDaemonTestCase(DaemonTestCase):
         """
@@ -159,7 +149,8 @@ if not sys.platform.startswith("win"):
         """
 
         def setUp(self):
-            super(WSTunnelClientDaemonTestCase, self).setUp()
+            #super(WSTunnelClientDaemonTestCase, self).setUp()
+            self.log_file, self.pid_file = setup_logging()
 
             with open(os.path.join(fixture, "wstuncltd.yml")) as f:
                 self.tun_conf = yaml.load(f.read())
@@ -173,13 +164,20 @@ if not sys.platform.startswith("win"):
             self.daemon = WSTunnelClientDaemon(self.tun_conf)
             self.daemon.hush = lambda **kwargs: 0
 
+        def test_create_logging_directory(self):
+            """
+            Tests automatic creation of logging directory through monkey patch on RotatingFileHandler
+            """
+            self.assertTrue(os.path.exists(os.path.dirname(self.log_file)))
+
     class WSTunnelServerDaemonTestCase(DaemonTestCase):
         """
         TestCase for the server tunnel endpoint in daemon mode
         """
 
         def setUp(self):
-            super(WSTunnelServerDaemonTestCase, self).setUp()
+            # super(WSTunnelServerDaemonTestCase, self).setUp()
+            self.log_file, self.pid_file = setup_logging()
 
             with open(os.path.join(fixture, "wstunsrvd.yml")) as f:
                 self.tun_conf = yaml.load(f.read())
@@ -193,6 +191,12 @@ if not sys.platform.startswith("win"):
             self.daemon = WSTunnelServerDaemon(self.tun_conf)
             self.daemon.hush = lambda **kwargs: 0
 
+        def test_create_logging_directory(self):
+            """
+            Tests automatic creation of logging directory through monkey patch on RotatingFileHandler
+            """
+            self.assertTrue(os.path.exists(os.path.dirname(self.log_file)))
+
     class WSTunnelSSLClientDaemonTestCase(DaemonTestCase):
         """
         TestCase for the ssl client tunnel endpoint in daemon mode
